'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _pipe = require('./pipe');

var _pipe2 = _interopRequireDefault(_pipe);

var _types = require('./types');

var _arr = require('./arr');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getKeys = function getKeys(obj) {
  return Object.keys(obj);
};
var findKey = function findKey(lookupObj) {
  return function (arr) {
    return arr.find(function (key) {
      return !!lookupObj[key];
    });
  };
};
var getValue = function getValue(lookupObj) {
  return function (key) {
    return lookupObj[key];
  };
};

var DeeplinkParser = {
  routes: {},

  config: function config() {
    var routes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    DeeplinkParser.routes = routes;
  },

  parse: function parse() {
    var payload = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    if (!(0, _types.isObject)(payload)) {
      return {};
    }

    var routes = DeeplinkParser.routes;

    // Find the key that is used to config the route

    var routeConfig = (0, _pipe2.default)(getKeys, _arr.lowercase, findKey(routes), getValue(routes))(payload);

    // Generate navigation action
    var routeName = routeConfig.routeName,
        params = routeConfig.params;


    var navigationAction = {
      routeName: (0, _types.isFunc)(routeName) ? routeName(payload) : routeName
    };

    if (params) {
      navigationAction.params = (0, _types.isFunc)(params) ? params(payload) : params;
    }

    if (__DEV__) {
      console.log('(DeeplinkParser) navigationAction:', navigationAction);
    }

    return navigationAction;
  }
};

exports.default = DeeplinkParser;